/* ----------------------------------------------------------------------

	CNFTEST sample for Microsoft ActiveX Conferencing API

	Unpublished work.
	Copyright (c) 1996, Microsoft Corporation
	All rights reserved.

	dlg.c

	Dialogs

  ---------------------------------------------------------------------- */

#include "main.h"

#include "resource.h"
#define IDR_ADDR_FIRST     IDR_ADDR_UNKNOWN
#define IDR_ADDR_LAST      IDR_ADDR_ISDN

// Local dialog procs
LRESULT CALLBACK ConferenceDlgProc(HWND hdlg, UINT uMsg, WPARAM wparam, LPARAM lparam);



/*  D L G  C O N F E R E N C E  C O N N E C T */
/*----------------------------------------------------------------------------
    %%Function: DlgConferenceConnect
 
----------------------------------------------------------------------------*/
BOOL DlgConferenceConnect(VOID)
{
	ASSERT((IDR_ADDR_UNKNOWN - IDR_ADDR_FIRST) == CONF_ADDR_UNKNOWN);
	ASSERT((IDR_ADDR_IP - IDR_ADDR_FIRST) == CONF_ADDR_IP);
	ASSERT((IDR_ADDR_MACHINE - IDR_ADDR_FIRST) == CONF_ADDR_MACHINENAME);
	ASSERT((IDR_ADDR_PSTN - IDR_ADDR_FIRST) == CONF_ADDR_PSTN);

	ASSERT((IDC_MT_DATA  - IDC_MT_DATA) == 0);
	ASSERT((IDC_MT_AUDIO - IDC_MT_DATA) == 1);
	ASSERT((IDC_MT_VIDEO - IDC_MT_DATA) == 2);

	return (0 == DialogBox(ghInst, MAKEINTRESOURCE(IDD_CONFERENCE),
		ghwndMain, (DLGPROC)ConferenceDlgProc));
}


/*  C O N F E R E N C E  D L G  P R O C */
/*----------------------------------------------------------------------------
    %%Function: ConferenceDlgProc
 
----------------------------------------------------------------------------*/
LRESULT CALLBACK ConferenceDlgProc(HWND hdlg, UINT uMsg, WPARAM wparam, LPARAM lparam)
{
	switch (uMsg)
	{
	case WM_INITDIALOG:
		CenterWindow(hdlg, ghwndMain);

		SetDlgItemText(hdlg, IDE_CONFNAME, gPref.szConferenceName);
		SetDlgItemText(hdlg, IDE_ADDR, gPref.szDefName);
		SetDlgItemInt(hdlg, IDE_HCONF, (UINT) gPref.hConf, fFalse);
		CheckRadioButton(hdlg, IDR_ADDR_FIRST, IDR_ADDR_LAST,
				IDR_ADDR_FIRST + gPref.iAddrType);

		{ // check media types
			int id;
			DWORD dwFlag = 0x01;
			for (id = IDC_MT_DATA; id <= IDC_MT_VIDEO; id++)
			{
				CheckDlgButton(hdlg, id, 0 != (gPref.dwMediaType & dwFlag));
				dwFlag <<= 1;
			}
		}

   		return fTrue;

	case WM_COMMAND:
		switch (GET_WM_COMMAND_ID(wparam, lparam))
		{
		case IDOK:
			gPref.iAddrType = GetRadioButton(hdlg, IDR_ADDR_FIRST, IDR_ADDR_LAST)
				- IDR_ADDR_FIRST;

			GetDlgItemText(hdlg, IDE_CONFNAME,
				gPref.szConferenceName, sizeof(gPref.szConferenceName));
			GetDlgItemText(hdlg, IDE_ADDR,
				gPref.szDefName, sizeof(gPref.szDefName));
			gPref.hConf = (HCONF) GetDlgItemInt(hdlg, IDE_HCONF, NULL, fFalse);

			{ // check media types
				int id;
				DWORD dwFlag = 0x01;
				gPref.dwMediaType = 0;
				for (id = IDC_MT_DATA; id <= IDC_MT_VIDEO; id++)
				{
					if (IsDlgButtonChecked(hdlg, id))
						gPref.dwMediaType |= dwFlag;
					dwFlag <<= 1;
				}
			}

			EndDialog(hdlg, 0);
			return fTrue;

		case IDCANCEL:
			EndDialog(hdlg, 1);
			return fTrue;

		default:
			return fTrue;
		} /* switch (cmd) */

	default:
		break;
	} /* switch (uMsg) */

	return fFalse;
}


/*  G U I D  D L G  P R O C */
/*----------------------------------------------------------------------------
    %%Function: GuidDlgProc
 
----------------------------------------------------------------------------*/
LRESULT CALLBACK GuidDlgProc(HWND hdlg, UINT uMsg, WPARAM wparam, LPARAM lparam)
{
	switch (uMsg)
	{
	case WM_INITDIALOG:
	{
		CHAR sz[MAX_PATH];

		CenterWindow(hdlg, ghwndMain);

		GuidToSz(&gPref.guid, sz);
		SetDlgItemText(hdlg, IDE_GUID, sz);
		SetDlgItemText(hdlg, IDE_APPLICATION, gPref.szAppName);
		SetDlgItemText(hdlg, IDE_COMMANDLINE, gPref.szCmdLine);
		SetDlgItemText(hdlg, IDE_DIRECTORY,   gPref.szCurrDir);

   		return fTrue;
	}

	case WM_COMMAND:
		switch (GET_WM_COMMAND_ID(wparam, lparam))
		{
		case IDOK:
		{
			CHAR sz[MAX_PATH];

			GetDlgItemText(hdlg, IDE_APPLICATION,
				gPref.szAppName, sizeof(gPref.szAppName));
			GetDlgItemText(hdlg, IDE_COMMANDLINE,
				gPref.szCmdLine, sizeof(gPref.szCmdLine));
			GetDlgItemText(hdlg, IDE_DIRECTORY,
				gPref.szCurrDir, sizeof(gPref.szCurrDir));
			GetDlgItemText(hdlg, IDE_GUID, sz, sizeof(sz));
			SzToGuid(sz, &gPref.guid);

			EndDialog(hdlg, 0);
			return fTrue;
		}

		case IDCANCEL:
			EndDialog(hdlg, 1);
			return fTrue;

		default:
			return fTrue;
		} /* switch (cmd) */

	default:
		break;
	} /* switch (uMsg) */

	return fFalse;
}


/*  D L G  G U I D */
/*----------------------------------------------------------------------------
    %%Function: DlgGuid
 
----------------------------------------------------------------------------*/
BOOL DlgGuid(VOID)
{
	return (0 == DialogBox(ghInst, MAKEINTRESOURCE(IDD_SETGUID),
		ghwndMain, (DLGPROC)GuidDlgProc));
}



/*  R E M O T E  D L G  P R O C */
/*----------------------------------------------------------------------------
    %%Function: RemoteDlgProc
 
----------------------------------------------------------------------------*/
LRESULT CALLBACK RemoteDlgProc(HWND hdlg, UINT uMsg, WPARAM wparam, LPARAM lparam)
{
	switch (uMsg)
	{
	case WM_INITDIALOG:
	{
		CHAR sz[MAX_PATH];

		CenterWindow(hdlg, ghwndMain);

		GuidToSz(&gPref.guidRemote, sz);
		SetDlgItemText(hdlg, IDE_GUID, sz);
		SetDlgItemInt(hdlg,  IDE_USERID, gPref.dwRemoteId, fFalse);

   		return fTrue;
	}

	case WM_COMMAND:
		switch (GET_WM_COMMAND_ID(wparam, lparam))
		{
		case IDOK:
		{
			CHAR sz[MAX_PATH];

			gPref.dwRemoteId = GetDlgItemInt(hdlg, IDE_USERID, NULL, fFalse);

			GetDlgItemText(hdlg, IDE_GUID, sz, sizeof(sz));
			SzToGuid(sz, &gPref.guidRemote);

			EndDialog(hdlg, 0);
			return fTrue;
		}

		case IDCANCEL:
			EndDialog(hdlg, 1);
			return fTrue;

		default:
			return fTrue;
		} /* switch (cmd) */

	default:
		break;
	} /* switch (uMsg) */

	return fFalse;
}


/*  D L G  L A U N C H  R E M O T E */
/*----------------------------------------------------------------------------
    %%Function: DlgLaunchRemote
 
----------------------------------------------------------------------------*/
BOOL DlgLaunchRemote(VOID)
{
	return (0 == DialogBox(ghInst, MAKEINTRESOURCE(IDD_LAUNCHREMOTE),
		ghwndMain, (DLGPROC)RemoteDlgProc));
}



/*  D A T A  D L G  P R O C */
/*----------------------------------------------------------------------------
    %%Function: DataDlgProc
 
----------------------------------------------------------------------------*/
LRESULT CALLBACK DataDlgProc(HWND hdlg, UINT uMsg, WPARAM wparam, LPARAM lparam)
{
	switch (uMsg)
	{
	case WM_INITDIALOG:
	{
		CHAR sz[MAX_PATH];

		CenterWindow(hdlg, ghwndMain);

		GuidToSz(&gPref.guidRemote, sz);
		SetDlgItemText(hdlg, IDE_GUID, sz);
		SetDlgItemInt(hdlg,  IDE_USERID, gPref.dwRemoteId, fFalse);
		SetDlgItemText(hdlg, IDE_DATA, gPref.szData);

   		return fTrue;
	}

	case WM_COMMAND:
		switch (GET_WM_COMMAND_ID(wparam, lparam))
		{
		case IDOK:
		{
			CHAR sz[MAX_PATH];

			GetDlgItemText(hdlg, IDE_DATA, gPref.szData, sizeof(gPref.szData));
			gPref.dwRemoteId = GetDlgItemInt(hdlg, IDE_USERID, NULL, fFalse);

			GetDlgItemText(hdlg, IDE_GUID, sz, sizeof(sz));
			SzToGuid(sz, &gPref.guidRemote);

			EndDialog(hdlg, 0);
			return fTrue;
		}

		case IDCANCEL:
			EndDialog(hdlg, 1);
			return fTrue;

		default:
			return fTrue;
		} /* switch (cmd) */

	default:
		break;
	} /* switch (uMsg) */

	return fFalse;
}


/*  D L G  S E N D  D A T A */
/*----------------------------------------------------------------------------
    %%Function: DlgSendData
 
----------------------------------------------------------------------------*/
BOOL DlgSendData(VOID)
{
	return (0 == DialogBox(ghInst, MAKEINTRESOURCE(IDD_SENDDATA),
		ghwndMain, (DLGPROC)DataDlgProc));
}


